@@ -8,6 +8,9 @@ import os
 import openai
 import anthropic
 import google.generativeai as genai
+import requests
+from pathlib import Path
+import toml
 
 
 @dataclass
@@ -38,7 +41,7 @@ class LLM(ABC):
 class OpenAILLM(LLM):
     """OpenAI LLM implementation."""
     
-    def __init__(self, api_key: Optional[str] = None, model: str = "gpt-4o-mini", **kwargs):
+    def __init__(self, api_key: Optional[str] = None, model: str = "o4-mini", **kwargs):
         self.api_key = api_key or os.getenv("OPENAI_API_KEY")
         if not self.api_key:
             raise ValueError("OpenAI API key required. Set OPENAI_API_KEY environment variable or pass api_key parameter.")
@@ -52,11 +55,17 @@ class OpenAILLM(LLM):
             "model": self.model,
             "messages": messages
         }
-        
+
+        # Set appropriate max tokens for different models
+        if self.model in ["o1", "o1-mini", "o1-preview", "o4-mini"]:
+            kwargs["max_completion_tokens"] = 16384
+        else:
+            kwargs["max_tokens"] = 16384
+
         if tools:
             kwargs["tools"] = [{"type": "function", "function": tool} for tool in tools]
             kwargs["tool_choice"] = "auto"
-        
+
         response = self.client.chat.completions.create(**kwargs)
         message = response.choices[0].message
         
@@ -95,7 +104,7 @@ class AnthropicLLM(LLM):
         
         kwargs = {
             "model": self.model,
-            "max_tokens": 4096,
+            "max_tokens": 16384,
             "messages": anthropic_messages
         }
         
@@ -268,7 +277,7 @@ class GeminiLLM(LLM):
         
         # Configure generation with tools if provided
         generation_config = genai.GenerationConfig(
-            max_output_tokens=4096,
+            max_output_tokens=16384,
         )
         
         # If we have tools, use the GenerativeModel with tools directly
@@ -593,6 +602,110 @@ MODEL_REGISTRY = {
 }
 
 
+class OpenOnionLLM(LLM):
+    """OpenOnion managed keys LLM implementation using OpenAI-compatible API."""
+
+    def __init__(self, api_key: Optional[str] = None, model: str = "co/o4-mini", **kwargs):
+        # For co/ models, api_key is actually the auth token
+        self.auth_token = api_key or self._get_auth_token()
+        if not self.auth_token:
+            raise ValueError(
+                "No authentication token found for co/ models.\n"
+                "Run 'co auth' to authenticate first."
+            )
+
+        self.model = model
+
+        # Determine base URL for OpenAI-compatible endpoint
+        if os.getenv("OPENONION_DEV") or os.getenv("ENVIRONMENT") == "development":
+            base_url = "http://localhost:8000/v1"
+        else:
+            base_url = "https://oo.openonion.ai/v1"
+
+        # Use OpenAI client with OpenOnion endpoint
+        self.client = openai.OpenAI(
+            base_url=base_url,
+            api_key=self.auth_token
+        )
+    
+    def _get_auth_token(self) -> Optional[str]:
+        """Get authentication token from environment or local config."""
+        # First check environment variable (from .env file)
+        token = os.getenv("OPENONION_API_KEY")
+        if token:
+            return token
+
+        # Try current directory first, then parent directories, then home
+        config_paths = [
+            Path.cwd() / ".co" / "config.toml",
+            Path.cwd().parent / ".co" / "config.toml",
+            Path.cwd().parent.parent / ".co" / "config.toml",
+            Path.home() / ".connectonion" / ".co" / "config.toml"
+        ]
+
+        # Also check if we're running from a subdirectory
+        # Look for .co in the same directory as the script being run
+        import sys
+        if sys.argv[0]:
+            script_dir = Path(sys.argv[0]).parent.absolute()
+            config_paths.insert(0, script_dir / ".co" / "config.toml")
+
+        for config_path in config_paths:
+            if config_path.exists():
+                try:
+                    config = toml.load(config_path)
+                    if "auth" in config and "token" in config["auth"]:
+                        return config["auth"]["token"]
+                except Exception:
+                    continue
+
+        return None
+    
+    def complete(self, messages: List[Dict[str, Any]], tools: Optional[List[Dict[str, Any]]] = None) -> LLMResponse:
+        """Complete a conversation with optional tool support using OpenAI-compatible API."""
+        kwargs = {
+            "model": self.model,
+            "messages": messages
+        }
+
+        # Handle special requirements for o4-mini
+        if "o4-mini" in self.model:
+            # o4-mini requires max_completion_tokens instead of max_tokens
+            kwargs["max_completion_tokens"] = 16384
+            kwargs["temperature"] = 1
+        else:
+            kwargs["max_tokens"] = 16384
+
+        # Add tools if provided
+        if tools:
+            kwargs["tools"] = [{"type": "function", "function": tool} for tool in tools]
+            kwargs["tool_choice"] = "auto"
+
+        try:
+            response = self.client.chat.completions.create(**kwargs)
+            message = response.choices[0].message
+
+            # Parse tool calls if present
+            tool_calls = []
+            if hasattr(message, 'tool_calls') and message.tool_calls:
+                for tc in message.tool_calls:
+                    tool_calls.append(ToolCall(
+                        name=tc.function.name,
+                        arguments=json.loads(tc.function.arguments) if isinstance(tc.function.arguments, str) else tc.function.arguments,
+                        id=tc.id
+                    ))
+
+            return LLMResponse(
+                content=message.content,
+                tool_calls=tool_calls,
+                raw_response=response
+            )
+
+        except Exception as e:
+            error_msg = f"OpenOnion API error: {str(e)}"
+            raise ValueError(error_msg)
+
+
 def create_llm(model: str, api_key: Optional[str] = None, **kwargs) -> LLM:
     """Factory function to create the appropriate LLM based on model name.
     
@@ -607,6 +720,10 @@ def create_llm(model: str, api_key: Optional[str] = None, **kwargs) -> LLM:
     Raises:
         ValueError: If the model is not recognized
     """
+    # Check if it's a co/ model (OpenOnion managed keys)
+    if model.startswith("co/"):
+        return OpenOnionLLM(api_key=api_key, model=model, **kwargs)
+    
     # Get provider from registry
     provider = MODEL_REGISTRY.get(model)
     
